;: Title: AMPL Plugin Definition - by scribbly
/*
***********************************************************
START AMPL Definition Header
Version=1.0.0
Prefix=MAT
Label=MAT Plugin
Library=MATPlugin_Includes.ahk
END AMPL Definition Header
***********************************************************
*/

#NoEnv

MAT_Version=1.0.0
MAT_Prefix=MAT
MAT_IncludeSet:=False
MAT_Library=MATPlugin_Includes.ahk
MAT_Label=MAT Plugin

ampl_AddFunctionText_Function=AddFunctionText
function_GetFieldNumber=GetFieldNumber
function_GetVariableValue=GetVariableValue
function_DisableCloseButton=DisableCloseButton

run_Direct:=False
if (%0%>0){
	if 1=\ABOUT
	  {
    	MAT_About()
      ExitApp 
		}
} else {
  run_Direct:=True
  MAT_Init()
	MAT_GetFunction( 1 , 10 , 10 )
	return
}

;
; Function: _Init
; Description:
;		This function is called when the function plugin is loaded into ScriptEditor.
; Syntax: PREFIX_Init()
; Parameters:
;		None
; Return Value:
;		Success - Integer
;			1 = failure
;			0 = success
; Remarks:
;		PREFIX must be unique for all AMPL Function Plugins.
;		PREFIX is set in the Definition Header, Init() AND the Auto Execute secrtion
; Related: [bbcode]None.
;
MAT_Init() {
global
	MAT_Error=1
	MAT_Version=1.0.0
	MAT_Prefix=MAT
	MAT_IncludeSet:=False
	MAT_Library=MATPlugin_Includes.ahk
	MAT_Label=MAT Plugin

	; Plugin Variables
	MAT_mode=
	MAT_speed=
	MAT_speedUpDown=
	
	; Read ini
  IniRead, MAT_programmepath, MAT_Plugin.ini, MAT, path
	if MAT_programmepath=ERROR
	{
    FileSelectFile, MAT_programmepath , 3, %A_SCRIPTDIR%, Please select the MouseAccelToggler.eze programme:, MAT Programme (MouseAccelToggler.exe)
		if ERRORLEVEL=1
		{
      MsgBox, 0, %MAT_Label%, The location of MouseAccelToggler must be loaded for this Plugin to function., 
			if run_Direct
			  ExitApp
      Return , 1
		}
	}
  IniWrite, %MAT_programmepath%, MAT_Plugin.ini, MAT, path
	; Do not edit the following line
	ampl_AddFunctionText_Function=AddFunctionText
	MAT_Error=0
	Return, MAT_Error
}

;
; Function: _GetVersion
; Description:
;		This function returns the Plugin Version.
; Syntax: PREFIX_GetVersion()
; Return Value:
;		Version String
; Remarks:
;		Any string can be returned, but should be the version
; Related: _Init
; MAT:
;		MAT_GetVersion() {
;     MAT_return:= MAT_Version . " by Perry Mowbray (2009-09-22)"
;		}
;
MAT_GetVersion() {
global MAT_Version
	if MAT_Version=
		MAT_Init()
	Return, MAT_Version
}

;
; Function: _About
; Description:
;		This function is called from AMPL ScriptEditor, and can give information about the Plugin.
; Syntax: PREFIX_About()
; Return Value:
;		None
; Remarks:
;		None.
; Related: _Init
; MAT:
;		MAT_About() {
;		global MAT_Version
;			if MAT_Version=
;				MAT_Init()
;     MsgBox, This is the MAT Plugin definition.`nVersion: %MAT_Version%
;		}
;
MAT_About() {
global MAT_Version
	if MAT_Version=
		MAT_Init()
  MsgBox, This is the MAT Plugin definition.`nVersion: %MAT_Version%
}

;
; Function: _GetFunction
; Description:
;		Passes control to the Plugin Library.[br][br]The Plugin will generally create a Gui Window to obtain input from the user.
; Syntax: PREFIX_GetFunction( WindowNumber , Window_X , Window_Y )
; Parameters:
;		WindowNumber - The Window Number to use if a Gui window is created
;			eg: Gui, %PREFIX_WindowNumber%: Default
;		Window_X - X Position of the AMPL Step window
;			Can be used for positioning a gui window
;		Window_Y - Y Position of the AMPL Step window
;			Can be used for positioning a gui window
; Return Value:
;		None
; Remarks:
;		All variables created should be prefixed by the Plugin Prefix
;   If a Gui Window is created the Close Button should be disabled, so that the window can be correctly destroyed.
; Related: _Init
; MAT:
;
MAT_GetFunction( MAT_WindowNumber , MAT_Window_X , MAT_Window_Y ) {
global MAT_Version, MAT_Label, run_Direct, MAT_programmepath
	if MAT_Version=
		MAT_Init()

	if not FileExist(MAT_programmepath)
	{
    MsgBox, 0, %MAT_Label%, The location of MouseAccelToggler must be loaded for this Plugin to function.,
		if run_Direct
		  ExitApp
    Return , 1
	}

  Gui, %MAT_WindowNumber%: Default
  Gui, Add, Text, w400,This plugin will help run MouseAccelToggler by skwire.`n
	Gui, Font, Bold
	Gui, Add, Text,x5 w50, Mode
	Gui, Font, Normal
	Gui, Add, DropDownList, x65 yp-3 w200 vMAT_mode gMAT_mode , On||Off|Toggle|Ask at RunTime
	Gui, Font, Bold
	Gui, Add, Text,x5  w50, Speed
	Gui, Font, Normal
	Gui, Add, Edit, x65 yp-3 w200 vMAT_speed Number,
	Gui, Add, UpDown, vMAT_speedUpDown Range1-20,10
	Gui, Add, Button, x326 yp w80 h30 gMAT_Insert, Insert
	Gui, Add, Button, x326 yp+40 w80 h30 gMAT_Cancel, Cancel
	MAT_Window_X+=5
	MAT_Window_Y+=30
	Gui, Show, x%MAT_Window_X% y%MAT_Window_Y% w419, %MAT_Label% - v%MAT_Version%
	if run_Direct=False
		%function_DisableCloseButton%()
}

;
; Function: _Insert
; Description:
;		Calls the ampl_AddFunctionText Function with the string that will be inserted into the AMPL Code Before section
; Syntax: PREFIX_Insert()
; Return Value:
;		None
; Remarks:
;		All variables created should be prefixed by the Plugin Prefix
;		The Gui should be Destroyed before Returning
;		Call %ampl_AddFunctionText_Function% with the Plugin Prefix and the string to insert to insert the string into the code Before section.
;			MAT: [code]%ampl_AddFunctionText_Function%(MAT_Prefix , MAT_return)[/code]
; Related: _Init
; MAT:
;
MAT_Insert:
GUI, Submit, NoHide

ic="
cr=`n
MAT_return:= "cmd_fullPath:=" . ic . MAT_programmepath . ic . cr
if MAT_thisMode=Ask at RunTime
	MAT_return.="cmd_parameters:=MAT_AskParameters()" . cr
else
MAT_return.= "cmd_parameters:=" . ic . "mode=" . MAT_mode . A_SPACE . "speed=" . MAT_speed . ic . cr
MAT_return.= "Run, %cmd_fullpath% %cmd_parameters%" . cr . "ExitApp"
Gui, Destroy

if run_Direct
  ExitApp

%ampl_AddFunctionText_Function%(MAT_Prefix , MAT_return)
Return


;
; Function: _Cancel
; Description:
;		Calls the ampl_AddFunctionText Function with an empty string and cleans up any Gui Windows created
; Syntax: PREFIX_Cancel()
; Return Value:
;		None
; Remarks:
;		The Gui should be Destroyed before Returning
;		Call %ampl_AddFunctionText_Function% with the Plugin Prefix and an empty string.
;			MAT: [code]%ampl_AddFunctionText_Function%(MAT_Prefix , "")[/code]
; Related: _Init
; MAT:
;
MAT_Cancel:
MAT_return:=""
Gui, Destroy
if run_Direct
  ExitApp 
%ampl_AddFunctionText_Function%(MAT_Prefix , "")
Return

;
; Function: _IncludeDirective
; Description:
;   This function is called by AMPL ScriptEditor, which constructs the #Include statement for the script.
; Syntax: PREFIX_IncludeDirective()
; Return Value:
;		MAT_Library - String
; Remarks:
;		This function does not need to be edited.
; Related: None.
;
MAT_IncludeDirective() {
	global MAT_IncludeSet, MAT_Library
	
	MAT_return=
	if !MAT_IncludeSet
	{
	  MAT_return:= MAT_Library
	  MAT_IncludeSet:=True
	}
  Return , MAT_return
}

/*
**
** PLUGIN SUB-ROUTINES
**
*/
MAT_mode:
  GuiControlGet, MAT_thisMode , , MAT_mode, 
  MAT_hideParameters:=1
  if MAT_thisMode=Ask at RunTime
    MAT_hideParameters:=0
  GuiControl, Enable%MAT_hideParameters%, MAT_speed
Return
